@@ -7,6 +7,7 @@ import (
 
 	"github.com/confluentinc/kafka-rest-sdk-go/kafkarestv3"
 
+	"github.com/confluentinc/cli/v3/pkg/broker"
 	pcmd "github.com/confluentinc/cli/v3/pkg/cmd"
 	"github.com/confluentinc/cli/v3/pkg/errors"
 	"github.com/confluentinc/cli/v3/pkg/examples"
@@ -148,7 +149,7 @@ func DescribeTopic(cmd *cobra.Command, restClient *kafkarestv3.APIClient, restCo
 	output.Println()
 	list = output.NewList(cmd)
 	for name, value := range topic.Configs {
-		list.Add(&configOut{
+		list.Add(&broker.ConfigOut{
 			Name:  name,
 			Value: value,
 		})
