@@ -11,18 +11,19 @@ import (
 
 const (
 	dockerImageName             = "confluentinc/confluent-local:latest"
-	confluentLocalContainerName = "confluent-local"
 	localhostPrefix             = "http://localhost:%s"
 	localhost                   = "localhost"
 	kafkaRestNotReadySuggestion = "Kafka REST connection is not ready. Re-running the command may solve the issue."
 )
 
-func (c *Command) newKafkaCommand() *cobra.Command {
+func (c *command) newKafkaCommand() *cobra.Command {
 	cmd := &cobra.Command{
 		Use:   "kafka",
-		Short: "Manage a single-node instance of Apache Kafka.",
+		Short: "Manage a local instance of Apache Kafka.",
 	}
 
+	cmd.AddCommand(c.newKafkaBrokerCommand())
+	cmd.AddCommand(c.newKafkaClusterCommand())
 	cmd.AddCommand(c.newKafkaStartCommand())
 	cmd.AddCommand(c.newKafkaStopCommand())
 	cmd.AddCommand(c.newKafkaTopicCommand())
