@@ -136,6 +136,28 @@ func (s *StatementControllerTestSuite) TestExecuteStatementCancelsAndDeletesStat
 }
 
 func (s *StatementControllerTestSuite) TestExecuteStatementPrintsUserInfo() {
+	statementToExecute := "select 1;"
+	processedStatement := types.ProcessedStatement{
+		StatementName:  "test-statement",
+		StatusDetail:   "status detail message",
+		Status:         types.PENDING,
+		ServiceAccount: "sa-123",
+	}
+	completedStatement := processedStatement
+	completedStatement.Status = types.COMPLETED
+	s.store.EXPECT().ProcessStatement(statementToExecute).Return(&processedStatement, nil)
+	s.consoleParser.EXPECT().Read().Return(nil, nil).AnyTimes()
+	s.store.EXPECT().WaitPendingStatement(gomock.Any(), processedStatement).Return(&completedStatement, nil)
+	s.store.EXPECT().FetchStatementResults(completedStatement).Return(&completedStatement, nil)
+
+	stdout := testUtils.RunAndCaptureSTDOUT(s.T(), func() {
+		_, _ = s.statementController.ExecuteStatement(statementToExecute)
+	})
+
+	cupaloy.SnapshotT(s.T(), stdout)
+}
+
+func (s *StatementControllerTestSuite) TestExecuteStatementPrintsWarningWhenNoServiceAccountIsUsed() {
 	statementToExecute := "select 1;"
 	processedStatement := types.ProcessedStatement{
 		StatementName: "test-statement",
@@ -158,7 +180,7 @@ func (s *StatementControllerTestSuite) TestExecuteStatementPrintsUserInfo() {
 
 func (s *StatementControllerTestSuite) TestExecuteStatementWaitsForCompletedState() {
 	statementToExecute := "select 1;"
-	processedStatement := types.ProcessedStatement{Status: types.PENDING}
+	processedStatement := types.ProcessedStatement{Status: types.PENDING, ServiceAccount: "sa-123"}
 	runningStatement := types.ProcessedStatement{Status: types.RUNNING}
 	completedStatement := types.ProcessedStatement{Status: types.COMPLETED}
 	s.store.EXPECT().ProcessStatement(statementToExecute).Return(&processedStatement, nil)
@@ -178,7 +200,7 @@ func (s *StatementControllerTestSuite) TestExecuteStatementWaitsForCompletedStat
 
 func (s *StatementControllerTestSuite) TestExecuteStatementWaitsForFailedState() {
 	statementToExecute := "select 1;"
-	processedStatement := types.ProcessedStatement{Status: types.PENDING}
+	processedStatement := types.ProcessedStatement{Status: types.PENDING, ServiceAccount: "sa-123"}
 	runningStatement := types.ProcessedStatement{Status: types.RUNNING}
 	failedStatement := types.ProcessedStatement{Status: types.FAILED}
 	s.store.EXPECT().ProcessStatement(statementToExecute).Return(&processedStatement, nil)
@@ -198,7 +220,7 @@ func (s *StatementControllerTestSuite) TestExecuteStatementWaitsForFailedState()
 
 func (s *StatementControllerTestSuite) TestExecuteStatementWaitsForNonEmptyPageToken() {
 	statementToExecute := "select 1;"
-	processedStatement := types.ProcessedStatement{Status: types.PENDING}
+	processedStatement := types.ProcessedStatement{Status: types.PENDING, ServiceAccount: "sa-123"}
 	runningStatement := types.ProcessedStatement{Status: types.RUNNING}
 	runningStatementWithNextPage := types.ProcessedStatement{Status: types.RUNNING, PageToken: "not-empty"}
 	s.store.EXPECT().ProcessStatement(statementToExecute).Return(&processedStatement, nil)
@@ -218,7 +240,7 @@ func (s *StatementControllerTestSuite) TestExecuteStatementWaitsForNonEmptyPageT
 
 func (s *StatementControllerTestSuite) TestExecuteStatementReturnsWhenUserDetaches() {
 	statementToExecute := "select 1;"
-	processedStatement := types.ProcessedStatement{Status: types.PENDING}
+	processedStatement := types.ProcessedStatement{Status: types.PENDING, ServiceAccount: "sa-123"}
 	runningStatement := types.ProcessedStatement{Status: types.RUNNING}
 	s.store.EXPECT().ProcessStatement(statementToExecute).Return(&processedStatement, nil)
 	s.store.EXPECT().WaitPendingStatement(gomock.Any(), processedStatement).Return(&runningStatement, nil)
@@ -388,3 +410,18 @@ func TestIsDetachEvent(t *testing.T) {
 		})
 	}
 }
+
+func (s *StatementControllerTestSuite) TestCleanupStatement() {
+	statementToExecute := "select 1;"
+	processedStatement := types.ProcessedStatement{StatementName: "test-statement", Status: types.COMPLETED}
+	s.store.EXPECT().ProcessStatement(statementToExecute).Return(&processedStatement, nil)
+	s.consoleParser.EXPECT().Read().Return(nil, nil).AnyTimes()
+	s.store.EXPECT().WaitPendingStatement(gomock.Any(), processedStatement).Return(&processedStatement, nil)
+	s.store.EXPECT().FetchStatementResults(processedStatement).Return(&processedStatement, nil)
+	_, err := s.statementController.ExecuteStatement(statementToExecute)
+	require.Nil(s.T(), err)
+
+	require.Equal(s.T(), processedStatement.StatementName, s.statementController.(*StatementController).createdStatementName)
+	s.store.EXPECT().DeleteStatement(processedStatement.StatementName)
+	s.statementController.CleanupStatement()
+}
