@@ -14,7 +14,7 @@ func OutputErr(s string) {
 
 func OutputErrf(s string, args ...any) {
 	c := fColor.New(color.ErrorColor)
-	output.Printf(c.Sprint(s), args...)
+	output.Printf(c.Sprintln(s), args...)
 }
 
 func OutputInfo(s string) {
@@ -22,10 +22,15 @@ func OutputInfo(s string) {
 }
 
 func OutputInfof(s string, args ...any) {
-	output.Printf(s, args...)
+	output.Printf(s+"\n", args...)
 }
 
 func OutputWarn(s string) {
 	c := fColor.New(color.WarnColor)
 	output.Println(c.Sprint(s))
 }
+
+func OutputWarnf(s string, args ...any) {
+	c := fColor.New(color.WarnColor)
+	output.Printf(c.Sprintln(s), args...)
+}
