@@ -33,6 +33,10 @@ var ccloudV2Routes = []route{
 	{"/connect/v1/environments/{env}/clusters/{clusters}/connectors/{connector}/config", handleConnectorConfig},
 	{"/connect/v1/environments/{env}/clusters/{clusters}/connectors/{connector}/pause", handleConnectorPause},
 	{"/connect/v1/environments/{env}/clusters/{clusters}/connectors/{connector}/resume", handleConnectorResume},
+	{"/connect/v1/custom-connector-plugins", handleCustomPlugin},
+	{"/connect/v1/custom-connector-plugins/{id}", handleCustomPluginWithId},
+	{"/connect/v1/presigned-upload-url", handleCustomPluginUploadUrl},
+	{"/connect/v1/dummy-presigned-url", handleCustomPluginUploadFile},
 	{"/fcpm/v2/compute-pools", handleFcpmComputePools},
 	{"/fcpm/v2/compute-pools/{id}", handleFcpmComputePoolsId},
 	{"/fcpm/v2/iam-bindings", handleFcpmIamBindings},
