@@ -62,7 +62,11 @@ func handleFcpmComputePoolsId(t *testing.T) http.HandlerFunc {
 	return func(w http.ResponseWriter, r *http.Request) {
 		var computePool flinkv2.FcpmV2ComputePool
 		id := mux.Vars(r)["id"]
-
+		if id != "lfcp-123456" && id != "lfcp-222222" {
+			err := writeResourceNotFoundError(w)
+			require.NoError(t, err)
+			return
+		}
 		switch r.Method {
 		case http.MethodGet:
 			computePool = flinkv2.FcpmV2ComputePool{
@@ -75,6 +79,9 @@ func handleFcpmComputePoolsId(t *testing.T) http.HandlerFunc {
 				},
 				Status: &flinkv2.FcpmV2ComputePoolStatus{Phase: "PROVISIONED"},
 			}
+			if id == "lfcp-222222" {
+				computePool.Spec.DisplayName = flinkv2.PtrString("my-compute-pool-2")
+			}
 		case http.MethodPatch:
 			update := new(flinkv2.FcpmV2ComputePool)
 			err := json.NewDecoder(r.Body).Decode(update)
